@@ -36,8 +36,17 @@ class HeaderEncoder(object):
         return "{}.{}".format(self.header_prefix, key)
 
     def get_message_headers(self, worker_ctx):
+        data = worker_ctx.context_data
+
+        if None in data.values():
+            _log.warn(
+                'Attempted to publish unserialisable header value. '
+                'Headers with a value of `None` will be dropped from '
+                'the payload. {}'.format(data))
+
         headers = {self._get_header_name(key): value
-                   for key, value in worker_ctx.context_data.items()}
+                   for key, value in data.items()
+                   if value is not None}
         return headers
 
 
